summary refs log tree commit diff stats
path: root/src/fe-gtk/sexy-iso-codes.h
diff options
context:
space:
mode:
authorTingPing <tingping@tingping.se>2013-10-01 12:09:17 -0400
committerTingPing <tingping@tingping.se>2013-10-03 16:23:46 -0400
commitf6dd61cb024d34df477db55edf8fc2f560a49480 (patch)
tree1a60d6efe3d19bee3d68a5ac1cdc0dc437a9856a /src/fe-gtk/sexy-iso-codes.h
parenteb93130cd3a846650dfbb972194190e91564df02 (diff)
Update to gtkspell3's iso code lookup
This no longer requires libxml
so now there is no reason for this to be optional
Diffstat (limited to 'src/fe-gtk/sexy-iso-codes.h')
-rw-r--r--src/fe-gtk/sexy-iso-codes.h54
1 files changed, 28 insertions, 26 deletions
diff --git a/src/fe-gtk/sexy-iso-codes.h b/src/fe-gtk/sexy-iso-codes.h
index 771c8eb0..52949c72 100644
--- a/src/fe-gtk/sexy-iso-codes.h
+++ b/src/fe-gtk/sexy-iso-codes.h
@@ -1,35 +1,37 @@
 /*
  *  Copyright (C) 2005 Nathan Fredrickson
  *  Borrowed from Galeon, renamed, and simplified to only use iso-codes with no
  *  fallback method.
  *
  *  Copyright (C) 2004 Christian Persch
  *  Copyright (C) 2004 Crispin Flowerday
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-#ifndef GTKSPELL_ISO_CODES_H
-#define GTKSPELL_ISO_CODES_H
+#ifndef GTK_SPELL_CODETABLE_H
+#define GTK_SPELL_CODETABLE_H
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-char *  gtkspell_iso_codes_lookup_name_for_code (const char *code);
+void codetable_init (void);
+void codetable_free (void);
+void codetable_lookup (const gchar *language_code,
+	const gchar **language_name,
+	const gchar **country_name);
 
 G_END_DECLS
 
-#endif
+#endif /* GTK_SPELL_CODETABLE_H */
\ No newline at end of file
@@ -1,35 +1,37 @@
-/*
- *  Copyright (C) 2005 Nathan Fredrickson
- *  Borrowed from Galeon, renamed, and simplified to only use iso-codes with no
- *  fallback method.
- *
- *  Copyright (C) 2004 Christian Persch
- *  Copyright (C) 2004 Crispin Flowerday
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
- */
+/* gtkspell - a spell-checking addon for GTK's TextView widget
+* Copyright (c) 2013 Sandro Mani
+*
+* Based on gtkhtml-editor-spell-language.c code which is
+* Copyright (C) 2008 Novell, Inc.
+*
+*    This program is free software; you can redistribute it and/or modify
+*    it under the terms of the GNU General Public License as published by
+*    the Free Software Foundation; either version 2 of the License, or
+*    (at your option) any later version.
+*
+*    This program is distributed in the hope that it will be useful,
+*    but WITHOUT ANY WARRANTY; without even the implied warranty of
+*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*    GNU General Public License for more details.
+*
+*    You should have received a copy of the GNU General Public License along
+*    with this program; if not, write to the Free Software Foundation, Inc.,
+*    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 